@@ -2,7 +2,7 @@ package Test2::Harness::UI;
 use strict;
 use warnings;
 
-our $VERSION = '0.000071';
+our $VERSION = '0.000072';
 
 use Router::Simple;
 use Text::Xslate(qw/mark_raw/);
@@ -68,8 +68,12 @@ sub init {
     $router->connect('/coverage/:source'        => {controller => 'Test2::Harness::UI::Controller::Coverage'});
     $router->connect('/coverage/:source/:user'  => {controller => 'Test2::Harness::UI::Controller::Coverage'});
     $router->connect('/coverage/:source/delete' => {controller => 'Test2::Harness::UI::Controller::Coverage', delete => 1});
-    $router->connect('/failed/:source'          => {controller => 'Test2::Harness::UI::Controller::Failed'});
-    $router->connect('/failed/:source/json'     => {controller => 'Test2::Harness::UI::Controller::Failed', json => 1});
+
+    $router->connect('/failed/:source'                 => {controller => 'Test2::Harness::UI::Controller::Failed'});
+    $router->connect('/failed/:source/json'            => {controller => 'Test2::Harness::UI::Controller::Failed', json => 1});
+    $router->connect('/failed/:project/:idx'           => {controller => 'Test2::Harness::UI::Controller::Failed', json => 1});
+    $router->connect('/failed/:project/:username'      => {controller => 'Test2::Harness::UI::Controller::Failed', json => 1});
+    $router->connect('/failed/:project/:username/:idx' => {controller => 'Test2::Harness::UI::Controller::Failed', json => 1});
 
     $router->connect('/download/:id' => {controller => 'Test2::Harness::UI::Controller::Download'});
 
